@@ -3,11 +3,11 @@ package storage
 import (
 	"context"
 	"fmt"
+	"k8s.io/apimachinery/pkg/fields"
 
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metainternalversion "k8s.io/apimachinery/pkg/apis/meta/internalversion"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/fields"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -73,19 +73,18 @@ func (m *PackageManifestStorage) List(ctx context.Context, options *metainternal
 		return nil, err
 	}
 
-	res, err := m.prov.List(namespace)
+	res, err := m.prov.List(namespace, labelSelector)
 	if err != nil {
 		return nil, k8serrors.NewInternalError(err)
 	}
 
-	// Filter by label selector
 	filtered := []operators.PackageManifest{}
 	for _, manifest := range res.Items {
-		if matches(manifest, name, labelSelector) {
+		if matches(manifest, name) {
 			filtered = append(filtered, manifest)
 		}
 	}
-	// Strip logo icons
+
 	for i := range filtered {
 		for j := range filtered[i].Status.Channels {
 			filtered[i].Status.Channels[j].CurrentCSVDesc.Icon = []operators.Icon{}
@@ -116,6 +115,7 @@ func (m *PackageManifestStorage) NamespaceScoped() bool {
 	return true
 }
 
+
 func nameFor(fs fields.Selector) (string, error) {
 	if fs == nil {
 		fs = fields.Everything()
@@ -129,9 +129,9 @@ func nameFor(fs fields.Selector) (string, error) {
 	return name, nil
 }
 
-func matches(pm operators.PackageManifest, name string, ls labels.Selector) bool {
+func matches(pm operators.PackageManifest, name string) bool {
 	if name == "" {
 		name = pm.GetName()
 	}
-	return ls.Matches(labels.Set(pm.GetLabels())) && pm.GetName() == name
-}
+	return pm.GetName() == name
+}
\ No newline at end of file
